@@ -550,6 +550,8 @@ typedef enum _MT_LOG_ID
     MT_MOS_MM_BIND_GPU_RESOURCE_VIRTUAL,
     MT_MOS_MM_UNBIND_GPU_RESOURCE_VIRTUAL,
     MT_ERR_CRITICAL_MESSAGE,
+    MT_MOS_ALLOCATE_MEMORY,
+    MT_MOS_DESTROY_MEMORY,
     MT_LOG_ID_CP_BASE = 0x01000000,
     MT_CP_HAL_NOT_INITIALIZED,
     MT_CP_HAL_FAIL,
@@ -707,34 +709,40 @@ typedef enum _MT_LOG_ID
     MT_VP_BLT_MCPYPARAM,
     MT_VP_USERFEATURE_CTRL,
     MT_VP_FTR_REPORT,
-    MT_VP_FEATURE_GRAPTH_ID_BASE = 0x02000200,
-    MT_VP_FEATURE_GRAPTH_CREATESWFILTERPIPE_START,
-    MT_VP_FEATURE_GRAPTH_CREATESWFILTERPIPE_END,
-    MT_VP_FEATURE_GRAPTH_SETUPEXECUTESWFILTER_START,
-    MT_VP_FEATURE_GRAPTH_SETUPEXECUTESWFILTER_END,
-    MT_VP_FEATURE_GRAPTH_EXECUTEFILTER,
-    MT_VP_FEATURE_GRAPTH_SWFILTERALPHA,
-    MT_VP_FEATURE_GRAPTH_SWFILTERBLENDING,
-    MT_VP_FEATURE_GRAPTH_SWFILTERCGC,
-    MT_VP_FEATURE_GRAPTH_SWFILTERCOLORFILL,
-    MT_VP_FEATURE_GRAPTH_SWFILTERCSC,
-    MT_VP_FEATURE_GRAPTH_SWFILTERDEINTERLACE,
-    MT_VP_FEATURE_GRAPTH_SWFILTERDENOISE,
-    MT_VP_FEATURE_GRAPTH_SWFILTERHDR,
-    MT_VP_FEATURE_GRAPTH_SWFILTERLUMAKEY,
-    MT_VP_FEATURE_GRAPTH_SWFILTERPROCAMP,
-    MT_VP_FEATURE_GRAPTH_SWFILTERROTMIR,
-    MT_VP_FEATURE_GRAPTH_SWFILTERSCALING,
-    MT_VP_FEATURE_GRAPTH_SWFILTERSTE,
-    MT_VP_FEATURE_GRAPTH_SWFILTERTCC,
-    MT_VP_FEATURE_GRAPTH_SWFILTERACE,
-    MT_VP_FEATURE_GRAPTH_SWFILTERCAPPIPE,
-    MT_VP_FEATURE_GRAPTH_SWFILTERDV,
-    MT_VP_FEATURE_GRAPTH_SWFILTERFDFB,
-    MT_VP_FEATURE_GRAPTH_SWFILTERLACE,
-    MT_VP_FEATURE_GRAPTH_SWFILTERS3D,
-    MT_VP_FEATURE_GRAPTH_SWFILTERSECURECOPY,
-    MT_VP_FEATURE_GRAPTH_SWFILTERVEBOXUPDATE,
+    MT_VP_FEATURE_GRAPH_ID_BASE = 0x02000200,
+    MT_VP_FEATURE_GRAPH_CREATESWFILTERPIPE_START,
+    MT_VP_FEATURE_GRAPH_CREATESWFILTERPIPE_END,
+    MT_VP_FEATURE_GRAPH_SETUPEXECUTESWFILTER_START,
+    MT_VP_FEATURE_GRAPH_SETUPEXECUTESWFILTER_END,
+    MT_VP_FEATURE_GRAPH_EXECUTEFILTER,
+    MT_VP_FEATURE_GRAPH_SWFILTERALPHA,
+    MT_VP_FEATURE_GRAPH_SWFILTERBLENDING,
+    MT_VP_FEATURE_GRAPH_SWFILTERCGC,
+    MT_VP_FEATURE_GRAPH_SWFILTERCOLORFILL,
+    MT_VP_FEATURE_GRAPH_SWFILTERCSC,
+    MT_VP_FEATURE_GRAPH_SWFILTERDEINTERLACE,
+    MT_VP_FEATURE_GRAPH_SWFILTERDENOISE,
+    MT_VP_FEATURE_GRAPH_SWFILTERHDR,
+    MT_VP_FEATURE_GRAPH_SWFILTERLUMAKEY,
+    MT_VP_FEATURE_GRAPH_SWFILTERPROCAMP,
+    MT_VP_FEATURE_GRAPH_SWFILTERROTMIR,
+    MT_VP_FEATURE_GRAPH_SWFILTERSCALING,
+    MT_VP_FEATURE_GRAPH_SWFILTERSTE,
+    MT_VP_FEATURE_GRAPH_SWFILTERTCC,
+    MT_VP_FEATURE_GRAPH_SWFILTERACE,
+    MT_VP_FEATURE_GRAPH_SWFILTERCAPPIPE,
+    MT_VP_FEATURE_GRAPH_SWFILTERDV,
+    MT_VP_FEATURE_GRAPH_SWFILTERFDFB,
+    MT_VP_FEATURE_GRAPH_SWFILTERLACE,
+    MT_VP_FEATURE_GRAPH_SWFILTERS3D,
+    MT_VP_FEATURE_GRAPH_SWFILTERSECURECOPY,
+    MT_VP_FEATURE_GRAPH_SWFILTERVEBOXUPDATE,
+    MT_VP_FEATURE_GRAPH_SWFILTERSTD,
+    MT_VP_FEATURE_GRAPH_INPUTSWFILTER,
+    MT_VP_FEATURE_GRAPH_OUTPUTSWFILTER,
+    MT_VP_FEATURE_GRAPH_INPUT_SURFACE_INFO,
+    MT_VP_FEATURE_GRAPH_INTERMEIDATE_SURFACE_INFO,
+    MT_VP_FEATURE_GRAPH_OUTPUT_SURFACE_INFO,
     MT_VP_HAL_ID_BASE = 0x02000400,
     MT_VP_HAL_PIPELINE_ADAPTER,
     MT_VP_HAL_PIPELINE_ADAPTER_EXT_ENTRY,
@@ -769,6 +777,9 @@ typedef enum _MT_LOG_ID
     MT_VP_HAL_POLICY_FLITER_FTR_COMBINE,
     MT_VP_HAL_FC_UPDATE_COMP_PARAM,
     MT_VP_HAL_FC_GET_CURBE_STATE,
+    MT_VP_HAL_DESTROY_SURF,
+    MT_VP_HAL_MEMORY_FOOTPRINT_EXECUTION_ENTRY,
+    MT_VP_HAL_MEMORY_FOOTPRINT_EXECUTION_EXIT,
     MT_VP_MHW_ID_BASE = 0x02002000,
     MT_VP_MHW_VE_SURFSTATE_INPUT,
     MT_VP_MHW_VE_SURFSTATE_OUT,
@@ -852,6 +863,8 @@ typedef enum _MT_PARAM_ID
     MT_COMMAND_GPUVA,
     MT_FUNC_NAME,
     MT_FUNC_LINE,
+    MT_MEMORY_PTR,
+    MT_MEMORY_SIZE,
     MT_PARAM_ID_MOS_BASE = 0x00001000,
     MT_MOS_STATUS,
     MT_MOS_GPU_NODE,
@@ -991,6 +1004,14 @@ typedef enum _MT_PARAM_ID
     MT_VP_HAL_MMCINUSE,
     MT_VP_HAL_FRC_MODE,
     MT_VP_HAL_CAPTURE_PIPE,
+    MT_VP_HAL_SURF_ALLOC_PARAM_PTR,
+    MT_VP_HAL_SURF_ALLOC_PARAM_MOS_SURF_PTR,
+    MT_VP_HAL_SURF_ALLOC_PARAM_IS_RES_OWNER,
+    MT_VP_HAL_SURF_ALLOC_PARAM_HANDLE,
+    MT_VP_HAL_SURF_ALLOC_PARAM_SIZE,
+    MT_VP_HAL_SURF_ALLOC_PARAM_NAME,
+    MT_VP_HAL_SURF_ALLOC_PARAM_PEAK_SIZE,
+    MT_VP_HAL_SURF_ALLOC_PARAM_TOTAL_SIZE,
     MT_PARAM_ID_VP_FEATURE_GRAPH_BASE = 0x02001400,
     MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT,
     MT_VP_FEATURE_GRAPH_FILTER_LAYERINDEXES_COUNT,
@@ -1058,6 +1079,22 @@ typedef enum _MT_PARAM_ID
     MT_VP_FEATURE_GRAPH_FILTER_ENABLES3D,
     MT_VP_FEATURE_GRAPH_FILTER_STEREOFORMAT,
     MT_VP_FEATURE_GRAPH_FILTER_VEBOXSTATECOPYNEEDED,
+    MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_ENABLE,
+    MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_TO_STDPARAM,
+    MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_TO_OUTPUT_SURFACE,
+    MT_VP_FEATURE_GRAPH_SURFACE_WIDTH,
+    MT_VP_FEATURE_GRAPH_SURFACE_HEIGHT,
+    MT_VP_FEATURE_GRAPH_SURFACE_PITCH,
+    MT_VP_FEATURE_GRAPH_SURFACE_COLORSPACE,
+    MT_VP_FEATURE_GRAPH_SURFACE_FORMAT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_LEFT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_TOP,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_RIGHT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_BOTTOM,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCDST_LEFT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCDST_TOP,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCDST_RIGHT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCDST_BOTTOM,
     MT_PARAM_ID_VP_MHW_BASE = 0x02002000,
     MT_VP_MHW_VE_SCALABILITY_EN,
     MT_VP_MHW_VE_SCALABILITY_USE_SFC,
