@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2020, Intel Corporation
+* Copyright (c) 2019-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -25,7 +25,9 @@
 //! \details
 //!
 #include "vphal_render_vebox_memdecomp.h"
+#include "mos_os_cp_interface_specific.h"
 #include "vphal_debug.h"
+#include "vp_utils.h"
 
 MediaVeboxDecompState::MediaVeboxDecompState():
     MediaMemDecompBaseState(),
@@ -43,8 +45,15 @@ MediaVeboxDecompState::~MediaVeboxDecompState()
 
     if (m_cpInterface)
     {
-        Delete_MhwCpInterface(m_cpInterface);
-        m_cpInterface = nullptr;
+        if(m_osInterface)
+        {
+            m_osInterface->pfnDeleteMhwCpInterface(m_cpInterface);
+            m_cpInterface = nullptr;
+        }
+        else
+        {
+            VPHAL_MEMORY_DECOMP_ASSERTMESSAGE("Failed to destroy cpInterface.");
+        }
     }
 
     if (m_veboxInterface)
@@ -200,7 +209,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
     targetSurface.Format     = Format_Invalid;
     targetSurface.OsResource = *outputResource;
 
-#if !defined(LINUX) && !defined(ANDROID) && !EMUL
+#if !defined(LINUX) && !defined(ANDROID) && !EMUL && !_VULKAN
     // for Double Buffer copy, clear the allocationInfo temply
     MOS_ZeroMemory(&targetSurface.OsResource.AllocationInfo, sizeof(SResidencyInfo));
 #endif
@@ -213,16 +222,11 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
 #if (_DEBUG || _RELEASE_INTERNAL)
     {
         // Read user feature key to force outputCompressed
-        MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-        MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-        MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
-            nullptr,
-            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED_ID,
-            &userFeatureData,
-            m_osInterface ? m_osInterface->pOsContext : nullptr));
-
-        outputCompressed = userFeatureData.bData ? true : false;
-
+        ReadUserSettingForDebug(
+            m_userSettingPtr,
+            outputCompressed,
+            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED,
+            MediaUserSetting::Group::Sequence);
     }
 #endif
 
@@ -257,6 +261,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
                 //non lockable resource enabled, we can't lock source surface
                 eStatus = MOS_STATUS_NULL_POINTER;
                 VPHAL_MEMORY_DECOMP_ASSERTMESSAGE("Failed to lock non-lockable input resource, buffer copy failed, eStatus:%d.\n", eStatus);
+                MT_ERR2(MT_VE_DECOMP_COPY, MT_SURF_IS_INPUT, 1, MT_VE_DECOMP_COPY_SURF_LOCK_STATUS, eStatus);
                 break;
             }
 
@@ -267,6 +272,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
                 eStatus = MOS_STATUS_NULL_POINTER;
                 m_osInterface->pfnUnlockResource(m_osInterface, &sourceSurface.OsResource);
                 VPHAL_MEMORY_DECOMP_ASSERTMESSAGE("Failed to lock non-lockable output resource, buffer copy failed, eStatus:%d.\n", eStatus);
+                MT_ERR2(MT_VE_DECOMP_COPY, MT_SURF_IS_OUTPUT, 1, MT_VE_DECOMP_COPY_SURF_LOCK_STATUS, eStatus);
                 break;
             }
             // This resource is a series of bytes. Is not 2 dimensional.
@@ -279,6 +285,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
             if (eStatus != MOS_STATUS_SUCCESS)
             {
                 VPHAL_MEMORY_DECOMP_ASSERTMESSAGE("Failed to copy linear buffer from source to target, eStatus:%d.\n", eStatus);
+                MT_ERR1(MT_VE_DECOMP_COPY, MT_MOS_STATUS, eStatus);
                 break;
             }
         } while (false);
@@ -288,6 +295,17 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
         return eStatus;
     }
 
+    // if source surface or target surface is non-64align linear, return error here
+    if((sourceSurface.dwPitch%64 != 0 && sourceSurface.TileType == MOS_TILE_LINEAR) ||
+       (targetSurface.dwPitch%64 != 0 && targetSurface.TileType == MOS_TILE_LINEAR))
+    {
+        eStatus = MOS_STATUS_INVALID_PARAMETER;
+        VPHAL_MEMORY_DECOMP_ASSERTMESSAGE("VEBOX does not support non-64align pitch linear surface, eStatus:%d.\n", eStatus);
+        MT_ERR2(MT_VE_DECOMP_COPY, MT_SURF_PITCH, sourceSurface.dwPitch, MT_SURF_PITCH, targetSurface.dwPitch);
+        MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_END, nullptr, 0, nullptr, 0);
+        return eStatus;
+    }
+
     //Get context before proceeding
     auto gpuContext = m_osInterface->CurrentGpuContextOrdinal;
 
@@ -341,7 +359,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
     targetSurface.Format = Format_Invalid;
     targetSurface.OsResource = *outputResource;
 
-#if !defined(LINUX) && !defined(ANDROID) && !EMUL
+#if !defined(LINUX) && !defined(ANDROID) && !EMUL && !_VULKAN
     // for Double Buffer copy, clear the allocationInfo temply
     MOS_ZeroMemory(&targetSurface.OsResource.AllocationInfo, sizeof(SResidencyInfo));
 #endif
@@ -354,15 +372,11 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
 #if (_DEBUG || _RELEASE_INTERNAL)
     {
         // Read user feature key to Force outputCompressed
-        MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-        MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-        MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
-            nullptr,
-            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED_ID,
-            &userFeatureData,
-            m_osInterface ? m_osInterface->pOsContext : nullptr));
-
-        outputCompressed = userFeatureData.bData ? true : false;
+        ReadUserSettingForDebug(
+            m_userSettingPtr,
+            outputCompressed,
+            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED,
+            MediaUserSetting::Group::Sequence);
     }
 #endif
 
@@ -456,7 +470,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryTileConvert(
     targetSurface.Format = Format_Invalid;
     targetSurface.OsResource = *outputResource;
 
-#if !defined(LINUX) && !defined(ANDROID) && !EMUL
+#if !defined(LINUX) && !defined(ANDROID) && !EMUL && !_VULKAN
     // for Double Buffer copy, clear the allocationInfo temply
     MOS_ZeroMemory(&targetSurface.OsResource.AllocationInfo, sizeof(SResidencyInfo));
 #endif
@@ -470,6 +484,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryTileConvert(
         sourceSurface.TileType == MOS_TILE_LINEAR)
     {
         VPHAL_MEMORY_DECOMP_NORMALMESSAGE("unsupport linear to linear convert, return unsupport feature");
+        MT_ERR2(MT_VE_DECOMP_COPY, MT_SURF_TILE_TYPE, MOS_TILE_LINEAR, MT_SURF_TILE_TYPE, MOS_TILE_LINEAR);
         return MOS_STATUS_PLATFORM_NOT_SUPPORTED;
     }
 
@@ -479,6 +494,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryTileConvert(
         if (!IsFormatSupported(&sourceSurface))
         {
             VPHAL_MEMORY_DECOMP_NORMALMESSAGE("unsupport processing format, return unsupport feature");
+            MT_ERR2(MT_VE_DECOMP_COPY, MT_SURF_MOS_FORMAT, sourceSurface.Format, MT_SURF_IS_INPUT, 1);
             return MOS_STATUS_PLATFORM_NOT_SUPPORTED;
         }
 
@@ -490,6 +506,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryTileConvert(
         if (!IsFormatSupported(&targetSurface))
         {
             VPHAL_MEMORY_DECOMP_NORMALMESSAGE("unsupport processing format, return unsupport feature");
+            MT_ERR2(MT_VE_DECOMP_COPY, MT_SURF_MOS_FORMAT, targetSurface.Format, MT_SURF_IS_OUTPUT, 1);
             return MOS_STATUS_PLATFORM_NOT_SUPPORTED;
         }
 
@@ -542,7 +559,7 @@ MOS_STATUS MediaVeboxDecompState::Initialize(
     MHW_VEBOX_GPUNODE_LIMIT     GpuNodeLimit;
     MOS_GPU_NODE                VeboxGpuNode;
     MOS_GPU_CONTEXT             VeboxGpuContext;
-    RENDERHAL_SETTINGS          RenderHalSettings;
+    RENDERHAL_SETTINGS_LEGACY   RenderHalSettings;
 
     eStatus = MOS_STATUS_SUCCESS;
 
@@ -556,6 +573,8 @@ MOS_STATUS MediaVeboxDecompState::Initialize(
     m_mhwMiInterface  = mhwMiInterface;
     m_veboxInterface  = veboxInterface;
 
+    m_userSettingPtr  = m_osInterface->pfnGetUserSettingInstance(m_osInterface);
+
     // Set-Up Vebox decompression enable or not
     IsVeboxDecompressionEnabled();
 
@@ -917,6 +936,13 @@ bool MediaVeboxDecompState::IsFormatSupported(PMOS_SURFACE surface)
         surface->dwHeight = surface->dwSize / surface->dwPitch;
     }
 
+    if (IS_RGB64_FLOAT_FORMAT(surface->Format) ||
+        IS_RGB64_FORMAT(surface->Format)       ||
+        surface->Format == Format_G32R32F)
+    {
+        surface->Format = Format_Y416;
+    }
+
     // Check if Sample Format is supported for decompression
     if (surface->Format != Format_NV12        &&
         surface->Format != Format_AYUV        &&
