@@ -642,6 +642,9 @@ void VpConfigValuesInit(
     pConfigValues->dwPrimaryCompressibleReported = LIBVA_VP_CONFIG_NOT_REPORTED;
     pConfigValues->dwPrimaryCompressModeReported = LIBVA_VP_CONFIG_NOT_REPORTED;
     pConfigValues->dwRTCacheSettingReported      = LIBVA_VP_CONFIG_NOT_REPORTED;
+#if (_DEBUG || _RELEASE_INTERNAL)
+    pConfigValues->dwRTOldCacheSettingReported   = LIBVA_VP_CONFIG_NOT_REPORTED;
+#endif
 }
 
 void VpFeatureReport(
@@ -704,6 +707,12 @@ void VpFeatureReport(
         __VPHAL_RT_Cache_Setting,
         pConfig->dwRTCacheSetting,
         MediaUserSetting::Group::Sequence);
+    //VP RT Old Cache Usage
+    ReportUserSettingForDebug(
+        userSettingPtr,
+        __VPHAL_RT_Old_Cache_Setting,
+        pConfig->dwRTOldCacheSetting,
+        MediaUserSetting::Group::Sequence);
 #endif
 #endif //(_DEBUG || _RELEASE_INTERNAL)
 }
