@@ -56,6 +56,15 @@ MOS_STATUS Av1VdencPipelineXe_LPM_Plus::Init(void *settings)
         EncodePreEncPacket* av1PreEncPkt = MOS_New(EncodePreEncPacket, this, task, m_hwInterface);
         ENCODE_CHK_STATUS_RETURN(RegisterPacket(encodePreEncPacket, av1PreEncPkt));
         ENCODE_CHK_STATUS_RETURN(av1PreEncPkt->Init());
+
+#if USE_CODECHAL_DEBUG_TOOL
+        uint32_t encodeMode = 0;
+        RUN_FEATURE_INTERFACE_RETURN(Av1VdencPreEnc, Av1FeatureIDs::preEncFeature, GetEncodeMode, encodeMode);
+        if (encodeMode == MediaEncodeMode::MANUAL_RES_PRE_ENC || encodeMode == MediaEncodeMode::AUTO_RES_PRE_ENC)
+        {
+            return MOS_STATUS_SUCCESS;
+        }
+#endif
     }
 
     Av1BrcInitPkt *brcInitpkt = MOS_New(Av1BrcInitPkt, this, task, m_hwInterface);
@@ -84,29 +93,4 @@ MOS_STATUS Av1VdencPipelineXe_LPM_Plus::Init(void *settings)
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS Av1VdencPipelineXe_LPM_Plus::Initialize(void *settings)
-{
-    ENCODE_FUNC_CALL();
-
-    CodechalSetting *codecSettings = (CodechalSetting *)settings;
-    ENCODE_CHK_NULL_RETURN(m_hwInterface);
-    ENCODE_CHK_STATUS_RETURN(m_hwInterface->Initialize(codecSettings));
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipelineXe_Lpm_Plus_Base::Initialize(settings));
-
-    CODECHAL_DEBUG_TOOL(
-        if (m_debugInterface != nullptr) {
-            MOS_Delete(m_debugInterface);
-        } m_debugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_debugInterface);
-        ENCODE_CHK_NULL_RETURN(m_mediaCopyWrapper);
-        ENCODE_CHK_STATUS_RETURN(m_debugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopyWrapper));
-
-        if (m_statusReportDebugInterface != nullptr) {
-            MOS_Delete(m_statusReportDebugInterface);
-        } m_statusReportDebugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_statusReportDebugInterface);
-        ENCODE_CHK_STATUS_RETURN(m_statusReportDebugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopyWrapper)););
-
-    return MOS_STATUS_SUCCESS;
-}
 }  // namespace encode
