@@ -215,47 +215,6 @@ MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::CreateFeatureManager()
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::Initialize(void *settings)
-{
-    ENCODE_FUNC_CALL();
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Initialize(settings));
-    ENCODE_CHK_STATUS_RETURN(InitMmcState());
-
-    CODECHAL_DEBUG_TOOL(
-        if (m_debugInterface != nullptr) {
-            MOS_Delete(m_debugInterface);
-        } m_debugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_debugInterface);
-        ENCODE_CHK_NULL_RETURN(m_mediaCopyWrapper);
-        ENCODE_CHK_STATUS_RETURN(
-            m_debugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopyWrapper));
-
-        if (m_statusReportDebugInterface != nullptr) {
-            MOS_Delete(m_statusReportDebugInterface);
-        } m_statusReportDebugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_statusReportDebugInterface);
-        ENCODE_CHK_STATUS_RETURN(
-            m_statusReportDebugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopyWrapper)););
-
-    ENCODE_CHK_STATUS_RETURN(GetSystemVdboxNumber());
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::Uninitialize()
-{
-    ENCODE_FUNC_CALL();
-
-    if (m_mmcState != nullptr)
-    {
-        MOS_Delete(m_mmcState);
-    }
-
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Uninitialize());
-
-    return MOS_STATUS_SUCCESS;
-}
-
 MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::ResetParams()
 {
     ENCODE_FUNC_CALL();
