@@ -308,6 +308,21 @@ public:
     static GMM_CLIENT_CONTEXT *GetGmmClientContext(
         MOS_STREAM_HANDLE streamState);
 
+    //!
+    //! \brief  Get PAT index from gmm
+    //!
+    //! \param  [in] gmmClient
+    //!         GMM client context
+    //! \param  [in] gmmResourceInfo
+    //!         gmm resource info
+    //!
+    //! \return unsigned int
+    //!         Pat index
+    //!
+    static unsigned int GetPATIndexFromGmm(
+        GMM_CLIENT_CONTEXT *gmmClient,
+        GMM_RESOURCE_INFO *gmmResourceInfo);
+
     //!
     //! \brief    Get current Gpu context priority
     //! \details  Get current Gpu context priority
@@ -1966,6 +1981,20 @@ public:
         MOS_STREAM_HANDLE streamState,
         uint32_t instanceIdx);
 
+    //!
+    //! \brief    Set Gpu Virtual Address for Debug
+    //! \details  Manually make page fault
+    //!
+    //! \param    [in] pResource
+    //!           Resource to set Gpu Address
+    //! \param    [in] address
+    //!           Address to set
+    //! \return   MOS_STATUS
+    //!
+    static MOS_STATUS SetGpuVirtualAddress(
+        PMOS_RESOURCE pResource, 
+        uint64_t      address);
+
 #endif // _DEBUG || _RELEASE_INTERNAL
 
     //!
@@ -2195,6 +2224,19 @@ public:
     //!
     static bool IsMultipleCodecDevicesInUse(PMOS_INTERFACE osInterface);
 
+
+    static MOS_STATUS SetMultiEngineEnabled(
+        PMOS_INTERFACE pOsInterface,
+        MOS_COMPONENT  component,
+        bool           enabled);
+
+    static MOS_STATUS GetMultiEngineStatus(
+        PMOS_INTERFACE pOsInterface,
+        PLATFORM      *platform,
+        MOS_COMPONENT  component,
+        bool          &isMultiDevices,
+        bool          &isMultiEngine);
+
     //!
     //! \brief  get latest virtual node for encoder and decoder
     //!
