@@ -753,99 +753,84 @@ MEDIA_CLASS_DEFINE_END(MosUtilDebug)
 
 #define MT_LOG(id, lvl)                                                     \
     {                                                                       \
-        int32_t head[] = {id, lvl};                                         \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 0, head, sizeof(head), nullptr, 0); \
+        int32_t _head[] = {id, lvl};                                         \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 0, _head, sizeof(_head), nullptr, 0); \
     }
 
 #define MT_LOG1(id, lvl, p1, v1)                                                      \
     {                                                                                 \
-        int32_t   head[] = {id, lvl};                                                 \
-        MT_PARAM param[] = {p1, v1};                                                  \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 1, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                 \
+        MT_PARAM  _param[] = {p1, v1};                                                  \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 1, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG2(id, lvl, p1, v1, p2, v2)                                              \
     {                                                                                 \
-        int32_t   head[] = {id, lvl};                                                 \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}};                                      \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 2, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                 \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}};                                      \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 2, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG3(id, lvl, p1, v1, p2, v2, p3, v3)                                      \
     {                                                                                 \
-        int32_t   head[] = {id, lvl};                                                 \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}};                            \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 3, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                 \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}};                            \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 3, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG4(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4)                              \
     {                                                                                 \
-        int32_t   head[] = {id, lvl};                                                 \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}};                  \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 4, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                 \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}};                  \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 4, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG5(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5)                                   \
     {                                                                                              \
-        int32_t   head[] = {id, lvl};                                                              \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}};                     \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 5, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                              \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}};                     \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 5, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG6(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6)                           \
     {                                                                                              \
-        int32_t   head[] = {id, lvl};                                                              \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}};           \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 6, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                              \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}};           \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 6, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_LOG7(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6, p7, v7)                   \
     {                                                                                              \
-        int32_t   head[] = {id, lvl};                                                              \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}, {p7, v7}}; \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 7, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id, lvl};                                                              \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}, {p7, v7}}; \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 7, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
-#define MT_LOG8(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6, p7, v7, p8, v8)                     \
-    {                                                                                                        \
-        int32_t  head[]  = {id, lvl};                                                                        \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}, {p7, v7}, {p8, v8}}; \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 8, head, sizeof(head), param, sizeof(param));           \
-    }
-
-#define MT_LOG9(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6, p7, v7, p8, v8, p9, v9)                       \
-    {                                                                                                                  \
-        int32_t  head[]  = {id, lvl};                                                                                  \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}, {p4, v4}, {p5, v5}, {p6, v6}, {p7, v7}, {p8, v8}, {p9, v9}}; \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_LOG, 9, head, sizeof(head), param, sizeof(param));                     \
-    }
-
-
 #define MT_ERR(id)                                                          \
     {                                                                       \
-        int32_t head[] = {id};                                              \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 0, head, sizeof(head), nullptr, 0); \
+        int32_t _head[] = {id};                                              \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 0, _head, sizeof(_head), nullptr, 0); \
     }
 
 #define MT_ERR1(id, p1, v1)                                                           \
     {                                                                                 \
-        int32_t   head[] = {id};                                                      \
-        MT_PARAM param[] = {p1, v1};                                                  \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 1, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id};                                                      \
+        MT_PARAM  _param[] = {p1, v1};                                                  \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 1, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_ERR2(id, p1, v1, p2, v2)                                                   \
     {                                                                                 \
-        int32_t   head[] = {id};                                                      \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}};                                      \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 2, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id};                                                      \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}};                                      \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 2, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #define MT_ERR3(id, p1, v1, p2, v2, p3, v3)                                           \
     {                                                                                 \
-        int32_t   head[] = {id};                                                      \
-        MT_PARAM param[] = {{p1, v1}, {p2, v2}, {p3, v3}};                            \
-        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 3, head, sizeof(head), param, sizeof(param)); \
+        int32_t   _head[] = {id};                                                      \
+        MT_PARAM  _param[] = {{p1, v1}, {p2, v2}, {p3, v3}};                            \
+        MosUtilities::MosTraceEvent(EVENT_MEDIA_ERR, 3, _head, sizeof(_head), _param, sizeof(_param)); \
     }
 
 #else // !MOS_MESSAGES_ENABLED
@@ -878,8 +863,6 @@ MEDIA_CLASS_DEFINE_END(MosUtilDebug)
 #define MT_LOG5(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5)
 #define MT_LOG6(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6)
 #define MT_LOG7(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6, p7, v7)
-#define MT_LOG8(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6, p7, v7, p8, v8)
-#define MT_LOG9(id, lvl, p1, v1, p2, v2, p3, v3, p4, v4, p5, v5, p6, v6, p7, v7, p8, v8, p9, v9)
 #define MT_ERR(id)
 #define MT_ERR1(id, p1, v1)
 #define MT_ERR2(id, p1, v1, p2, v2)
