@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -25,12 +25,8 @@
 //! \details  Common OS service across different platform
 //!
 
-#include <sstream>
-#include <fcntl.h>     //open
-#include <malloc.h>    // For memalign
-#include <stdlib.h>    // atoi atol
+#include <fcntl.h>
 #include <math.h>
-#include <time.h>     //for simulate random memory allcation failure
 #include "mos_os.h"
 #include "mos_utilities_specific.h"
 
@@ -41,27 +37,6 @@ MtEnable             MosUtilities::m_mosTraceEnable                     = false;
 MtFilter             MosUtilities::m_mosTraceFilter                     = {};
 MtLevel              MosUtilities::m_mosTraceLevel                      = {};
 
-bool MosUtilities::m_enableAddressDump = false;
-
-MOS_FUNC_EXPORT void MosUtilities::MosSetUltFlag(uint8_t ultFlag)
-{
-    if (MosUtilities::m_mosUltFlag != nullptr)
-    {
-        *MosUtilities::m_mosUltFlag = ultFlag;
-    }
-}
-
-MOS_FUNC_EXPORT int32_t MosUtilities::MosGetMemNinjaCounter()
-{
-    return m_mosMemAllocCounterNoUserFeature;
-}
-
-MOS_FUNC_EXPORT int32_t MosUtilities::MosGetMemNinjaCounterGfx()
-{
-    return m_mosMemAllocCounterNoUserFeatureGfx;
-}
-
-
 uint64_t MosUtilities::MosGetCurTime()
 {
     using us = std::chrono::microseconds;
@@ -74,36 +49,24 @@ uint64_t MosUtilities::MosGetCurTime()
     return usStartTime;
 }
 
-
 #if (_DEBUG || _RELEASE_INTERNAL)
 
 uint32_t MosUtilities::m_mosAllocMemoryFailSimulateMode = 0;
 uint32_t MosUtilities::m_mosAllocMemoryFailSimulateFreq = 0;
 uint32_t MosUtilities::m_mosAllocMemoryFailSimulateHint = 0;
 
-#define MEMORY_ALLOC_FAIL_SIMULATE_MODE_DEFAULT (0)
-#define MEMORY_ALLOC_FAIL_SIMULATE_MODE_RANDOM (1)
-#define MEMORY_ALLOC_FAIL_SIMULATE_MODE_TRAVERSE (2)
-
-#define MIN_MEMORY_ALLOC_FAIL_FREQ (1)      //max memory allcation fail rate 100%
-#define MAX_MEMORY_ALLOC_FAIL_FREQ (10000)  //min memory allcation fail rate 1/10000
-
-#define MosAllocMemoryFailSimulationEnabled                                         \
-    (m_mosAllocMemoryFailSimulateMode == MEMORY_ALLOC_FAIL_SIMULATE_MODE_RANDOM ||  \
-     m_mosAllocMemoryFailSimulateMode == MEMORY_ALLOC_FAIL_SIMULATE_MODE_TRAVERSE)
-
 void MosUtilities::MosInitAllocMemoryFailSimulateFlag(MediaUserSettingSharedPtr userSettingPtr)
 {
-    MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
-    uint32_t    value   = 0;
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    uint32_t   value   = 0;
 
     //default off for simulate random fail
-    m_mosAllocMemoryFailSimulateMode            = MEMORY_ALLOC_FAIL_SIMULATE_MODE_DEFAULT;
-    m_mosAllocMemoryFailSimulateFreq            = 0;
-    m_mosAllocMemoryFailSimulateHint            = 0;
+    m_mosAllocMemoryFailSimulateMode = MEMORY_ALLOC_FAIL_SIMULATE_MODE_DEFAULT;
+    m_mosAllocMemoryFailSimulateFreq = 0;
+    m_mosAllocMemoryFailSimulateHint = 0;
     if (m_mosAllocMemoryFailSimulateAllocCounter != nullptr)
     {
-        *m_mosAllocMemoryFailSimulateAllocCounter   = 0;
+        *m_mosAllocMemoryFailSimulateAllocCounter = 0;
     }
     else
     {
@@ -116,8 +79,8 @@ void MosUtilities::MosInitAllocMemoryFailSimulateFlag(MediaUserSettingSharedPtr
         __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_MODE,
         MediaUserSetting::Group::Device);
 
-    if ((value == MEMORY_ALLOC_FAIL_SIMULATE_MODE_DEFAULT)  ||
-        (value == MEMORY_ALLOC_FAIL_SIMULATE_MODE_RANDOM)   ||
+    if ((value == MEMORY_ALLOC_FAIL_SIMULATE_MODE_DEFAULT) ||
+        (value == MEMORY_ALLOC_FAIL_SIMULATE_MODE_RANDOM) ||
         (value == MEMORY_ALLOC_FAIL_SIMULATE_MODE_TRAVERSE))
     {
         m_mosAllocMemoryFailSimulateMode = value;
@@ -176,11 +139,11 @@ void MosUtilities::MosInitAllocMemoryFailSimulateFlag(MediaUserSettingSharedPtr
 bool MosUtilities::MosSimulateAllocMemoryFail(
     size_t      size,
     size_t      alignment,
-    const char  *functionName,
-    const char  *filename,
+    const char *functionName,
+    const char *filename,
     int32_t     line)
 {
-    bool  bSimulateAllocFail = false;
+    bool bSimulateAllocFail = false;
 
     if (!MosAllocMemoryFailSimulationEnabled)
     {
@@ -194,9 +157,7 @@ bool MosUtilities::MosSimulateAllocMemoryFail(
         if (Rn % m_mosAllocMemoryFailSimulateFreq == 1)
         {
             bSimulateAllocFail = true;
-            MOS_DEBUGMESSAGE(MOS_MESSAGE_LVL_CRITICAL, MOS_COMPONENT_OS, MOS_SUBCOMP_SELF, \
-                "Simulated Allocate Memory Fail (Rn=%d, SimulateAllocCounter=%d) for: functionName: %s, filename: %s, line: %d, size: %d, alignment: %d \n", \
-                Rn, (m_mosAllocMemoryFailSimulateAllocCounter ? *m_mosAllocMemoryFailSimulateAllocCounter : 0), functionName, filename, line, size, alignment);
+            MOS_DEBUGMESSAGE(MOS_MESSAGE_LVL_CRITICAL, MOS_COMPONENT_OS, MOS_SUBCOMP_SELF, "Simulated Allocate Memory Fail (Rn=%d, SimulateAllocCounter=%d) for: functionName: %s, filename: %s, line: %d, size: %d, alignment: %d \n", Rn, (m_mosAllocMemoryFailSimulateAllocCounter ? *m_mosAllocMemoryFailSimulateAllocCounter : 0), functionName, filename, line, size, alignment);
         }
         else
         {
@@ -208,9 +169,7 @@ bool MosUtilities::MosSimulateAllocMemoryFail(
         if (m_mosAllocMemoryFailSimulateAllocCounter &&
             (*m_mosAllocMemoryFailSimulateAllocCounter == m_mosAllocMemoryFailSimulateHint))
         {
-            MOS_DEBUGMESSAGE(MOS_MESSAGE_LVL_CRITICAL, MOS_COMPONENT_OS, MOS_SUBCOMP_SELF, \
-                "Simulated Allocate Memory Fail (hint=%d) for: functionName: %s, filename: %s, line: %d, size: %d \n", \
-                 m_mosAllocMemoryFailSimulateHint, functionName, filename, line, size, alignment);
+            MOS_DEBUGMESSAGE(MOS_MESSAGE_LVL_CRITICAL, MOS_COMPONENT_OS, MOS_SUBCOMP_SELF, "Simulated Allocate Memory Fail (hint=%d) for: functionName: %s, filename: %s, line: %d, size: %d \n", m_mosAllocMemoryFailSimulateHint, functionName, filename, line, size, alignment);
             bSimulateAllocFail = true;
         }
         else
@@ -229,54 +188,6 @@ bool MosUtilities::MosSimulateAllocMemoryFail(
 }
 #endif  // #if (_DEBUG || _RELEASE_INTERNAL)
 
-MOS_STATUS MosUtilities::MosUtilitiesInit(MediaUserSettingSharedPtr userSettingPtr)
-{
-    MOS_STATUS                  eStatus         = MOS_STATUS_SUCCESS;
-    MOS_OS_FUNCTION_ENTER;
-
-    eStatus = MosOsUtilitiesInit(userSettingPtr);
-
-#if (_DEBUG || _RELEASE_INTERNAL)
-
-#if COMMON_DLL_SEPARATION_SUPPORT
-    MosInitAllocFailSimulateFlagInCommon(userSettingPtr);
-#else
-    //Initialize MOS simulate random alloc memorflag
-    MosInitAllocMemoryFailSimulateFlag(userSettingPtr);
-#endif
-    eStatus = ReadUserSettingForDebug(
-        userSettingPtr,
-        MosUtilities::m_enableAddressDump,
-        "Resource Addr Dump Enable",
-        MediaUserSetting::Group::Device);
-#endif
-
-    return eStatus;
-}
-
-MOS_STATUS MosUtilities::MosUtilitiesClose(MediaUserSettingSharedPtr userSettingPtr)
-{
-    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-
-    MOS_OS_FUNCTION_ENTER;
-
-    // MOS_OS_Utilitlies_Close must be called right before end of function
-    // Because Memninja will calc mem leak here.
-    // Any memory allocation release after MosOsUtilitiesClose() will be treated as mem leak.
-    eStatus = MosOsUtilitiesClose(userSettingPtr);
-
-#if (_DEBUG || _RELEASE_INTERNAL)
-    //Reset Simulate Alloc Memory Fail flags
-#if COMMON_DLL_SEPARATION_SUPPORT
-    MosInitAllocFailSimulateFlagInCommon(userSettingPtr);
-#else
-    MosInitAllocMemoryFailSimulateFlag(userSettingPtr);
-#endif
-#endif
-
-    return eStatus;
-}
-
 #if MOS_MESSAGES_ENABLED
 void *MosUtilities::MosAlignedAllocMemoryUtils(
     size_t      size,
@@ -307,6 +218,9 @@ void  *MosUtilities::MosAlignedAllocMemory(
     {
         MosAtomicIncrement(m_mosMemAllocCounter);
         MOS_MEMNINJA_ALLOC_MESSAGE(ptr, size, functionName, filename, line);
+                MT_LOG2(MT_MOS_ALLOCATE_MEMORY, MT_NORMAL,
+                MT_MEMORY_PTR, (int64_t)(ptr),
+                MT_MEMORY_SIZE, static_cast<int64_t>(size));
     }
 
     return ptr;
@@ -328,7 +242,8 @@ void MosUtilities::MosAlignedFreeMemory(void *ptr)
     {
         MosAtomicDecrement(m_mosMemAllocCounter);
         MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line);
-
+        MT_LOG1(MT_MOS_DESTROY_MEMORY, MT_NORMAL,
+                MT_MEMORY_PTR, (int64_t)(ptr));        
         _aligned_free(ptr);
     }
 }
@@ -360,6 +275,9 @@ void *MosUtilities::MosAllocMemory(size_t size)
     {
         MosAtomicIncrement(m_mosMemAllocCounter);
         MOS_MEMNINJA_ALLOC_MESSAGE(ptr, size, functionName, filename, line);
+        MT_LOG2(MT_MOS_ALLOCATE_MEMORY, MT_NORMAL,
+                MT_MEMORY_PTR, (int64_t)(ptr),
+                MT_MEMORY_SIZE, static_cast<int64_t>(size));
     }
 
     return ptr;
@@ -394,6 +312,9 @@ void *MosUtilities::MosAllocAndZeroMemory(size_t size)
 
         MosAtomicIncrement(m_mosMemAllocCounter);
         MOS_MEMNINJA_ALLOC_MESSAGE(ptr, size, functionName, filename, line);
+        MT_LOG2(MT_MOS_ALLOCATE_MEMORY, MT_NORMAL,
+                MT_MEMORY_PTR, (int64_t)(ptr),
+                MT_MEMORY_SIZE, static_cast<int64_t>(size));
     }
 
     return ptr;
@@ -433,12 +354,16 @@ void *MosUtilities::MosReallocMemory(
         {
             MosAtomicDecrement(m_mosMemAllocCounter);
             MOS_MEMNINJA_FREE_MESSAGE(oldPtr, functionName, filename, line);
+            MT_LOG1(MT_MOS_DESTROY_MEMORY, MT_NORMAL, MT_MEMORY_PTR, (int64_t)(oldPtr)); 
         }
 
         if (newPtr != nullptr)
         {
             MosAtomicIncrement(m_mosMemAllocCounter);
             MOS_MEMNINJA_ALLOC_MESSAGE(newPtr, newSize, functionName, filename, line);
+            MT_LOG2(MT_MOS_ALLOCATE_MEMORY, MT_NORMAL,
+                MT_MEMORY_PTR, (int64_t)(newPtr),
+                MT_MEMORY_SIZE, static_cast<int64_t>(newSize));
         }
     }
 
@@ -468,7 +393,7 @@ void MosUtilities::MosFreeMemory(void  *ptr)
     {
         MosAtomicDecrement(m_mosMemAllocCounter);
         MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line);
-
+        MT_LOG1(MT_MOS_DESTROY_MEMORY, MT_NORMAL, MT_MEMORY_PTR, (int64_t)(ptr)); 
         free(ptr);
     }
 }
@@ -630,197 +555,6 @@ MOS_STATUS MosUtilities::MosAppendFileFromPtr(
     return eStatus;
 }
 
-/*****************************************************************************
-|
-|                           USER FEATURE Functions
-|
-*****************************************************************************/
-
-MOS_STATUS MosUtilities::MosUserFeatureOpen(
-    MOS_USER_FEATURE_TYPE KeyType,
-    const char            *pSubKey,
-    uint32_t              dwAccess,
-    void                  **pUFKey,
-    MOS_USER_FEATURE_KEY_PATH_INFO  *ufInfo)
-{
-    MOS_STATUS  eStatus;
-    void        *RootKey = 0;
-
-    MOS_OS_ASSERT(pSubKey);
-    MOS_OS_ASSERT(pUFKey);
-
-    if (KeyType == MOS_USER_FEATURE_TYPE_USER)
-    {
-        RootKey = (void *)UFKEY_INTERNAL;
-    }
-    else if (KeyType == MOS_USER_FEATURE_TYPE_SYSTEM)
-    {
-        RootKey = (void *)UFKEY_EXTERNAL;
-    }
-    else
-    {
-        MOS_OS_ASSERTMESSAGE("Invalid Key Type %d.", KeyType);
-        return MOS_STATUS_UNKNOWN;
-    }
-
-    if((eStatus = MosUserFeatureOpenKey(
-                             RootKey,
-                             pSubKey,
-                             0,
-                             dwAccess,
-                             pUFKey,
-                             ufInfo)) !=  MOS_STATUS_SUCCESS)
-    {
-        MOS_OS_NORMALMESSAGE("Unable to open user feature key %s.", pSubKey);
-    }
-
-    return eStatus;
-}
-
-MOS_STATUS MosUtilities::MosUserFeatureEnableNotification(
-    PMOS_USER_FEATURE_INTERFACE            pOsUserFeatureInterface,
-    PMOS_USER_FEATURE_NOTIFY_DATA          pNotification,
-    MOS_CONTEXT_HANDLE                     mosCtx)
-{
-    PMOS_USER_FEATURE_NOTIFY_DATA_COMMON    pNotifyCommon;
-    int32_t                                 bResult;
-    MOS_STATUS                              eStatus;
-    MOS_UNUSED(pOsUserFeatureInterface);
-
-    //---------------------------------------
-    MOS_OS_ASSERT(pNotification);
-    MOS_OS_ASSERT(pNotification->NotifyType != MOS_USER_FEATURE_NOTIFY_TYPE_INVALID);
-    MOS_OS_ASSERT(pNotification->pPath);
-    //---------------------------------------
-
-    MOS_USER_FEATURE_KEY_PATH_INFO *ufInfo = Mos_GetDeviceUfPathInfo((PMOS_CONTEXT)mosCtx);
-
-    // Reset the triggered flag
-    pNotification->bTriggered = false;
-
-    if (pNotification->pHandle == nullptr)
-    {
-        // Allocate private data as well
-        pNotification->pHandle = MOS_AllocAndZeroMemory(sizeof(MOS_USER_FEATURE_NOTIFY_DATA));
-        if(pNotification->pHandle == nullptr)
-        {
-            MOS_OS_ASSERTMESSAGE("Failed to allocate memory.");
-            return MOS_STATUS_NO_SPACE;
-        }
-    }
-    pNotifyCommon = (PMOS_USER_FEATURE_NOTIFY_DATA_COMMON)pNotification->pHandle;
-
-    // Open User Feature for Reading
-    if (pNotifyCommon->UFKey == 0)
-    {
-        if((eStatus = MosUserFeatureOpen(
-                          pNotification->Type,
-                          pNotification->pPath,
-                          KEY_READ,
-                          &pNotifyCommon->UFKey,
-                          ufInfo)) != MOS_STATUS_SUCCESS)
-        {
-            MOS_OS_ASSERTMESSAGE("Failed to open user feature for reading.");
-            return MOS_STATUS_USER_FEATURE_KEY_OPEN_FAILED;
-        }
-    }
-
-    // Create Event for notification
-    if (pNotifyCommon->hEvent == nullptr)
-    {
-        pNotifyCommon->hEvent = MosCreateEventEx(
-                                    nullptr,
-                                    nullptr,
-                                    0);
-        if(pNotifyCommon->hEvent == nullptr)
-        {
-            MOS_OS_ASSERTMESSAGE("Failed to allocate memory.");
-            return MOS_STATUS_NO_SPACE;
-        }
-    }
-
-    // Unregister wait event if already registered
-    if (pNotifyCommon->hWaitEvent)
-    {
-        if ((bResult = MosUnregisterWaitEx(pNotifyCommon->hWaitEvent)) == false)
-        {
-            MOS_OS_ASSERTMESSAGE("Unable to unregiser wait event.");
-            return MOS_STATUS_EVENT_WAIT_UNREGISTER_FAILED;
-        }
-        pNotifyCommon->hWaitEvent = nullptr;
-    }
-
-    // Register a Callback
-    if((eStatus = MosUserFeatureNotifyChangeKeyValue(
-                      pNotifyCommon->UFKey,
-                      false,
-                      pNotifyCommon->hEvent,
-                      true)) != MOS_STATUS_SUCCESS)
-    {
-        MOS_OS_ASSERTMESSAGE("Unable to setup user feature key notification.");
-        return MOS_STATUS_UNKNOWN;
-    }
-
-    // Create a wait object
-    if ((bResult = MosUserFeatureWaitForSingleObject(
-                                              &pNotifyCommon->hWaitEvent,
-                                              pNotifyCommon->hEvent,
-                                              (void *)MosUserFeatureCallback,
-                                              pNotification)) == false)
-    {
-        MOS_OS_ASSERTMESSAGE("Failed to create a wait object.");
-        return MOS_STATUS_EVENT_WAIT_REGISTER_FAILED;
-    }
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS MosUtilities::MosUserFeatureDisableNotification(
-    PMOS_USER_FEATURE_INTERFACE            pOsUserFeatureInterface,
-    PMOS_USER_FEATURE_NOTIFY_DATA          pNotification)
-{
-    PMOS_USER_FEATURE_NOTIFY_DATA_COMMON    pNotifyDataCommon;
-    int32_t                                 bResult;
-    MOS_STATUS                              eStatus;
-    MOS_UNUSED(pOsUserFeatureInterface);
-
-    //---------------------------------------
-    MOS_OS_ASSERT(pNotification);
-    //---------------------------------------
-
-    if (pNotification->pHandle)
-    {
-        pNotifyDataCommon = (PMOS_USER_FEATURE_NOTIFY_DATA_COMMON)
-            pNotification->pHandle;
-
-        if (pNotifyDataCommon->hWaitEvent)
-        {
-            if ((bResult = MosUnregisterWaitEx(pNotifyDataCommon->hWaitEvent)) == false)
-            {
-                MOS_OS_ASSERTMESSAGE("Unable to unregiser wait event.");
-                    return MOS_STATUS_EVENT_WAIT_UNREGISTER_FAILED;
-            }
-        }
-        if (pNotifyDataCommon->UFKey)
-        {
-            if ((eStatus = MosUserFeatureCloseKey(pNotifyDataCommon->UFKey)) != MOS_STATUS_SUCCESS)
-            {
-                MOS_OS_ASSERTMESSAGE("User feature key close failed.");
-                return eStatus;
-            }
-        }
-        if (pNotifyDataCommon->hEvent)
-        {
-            MosCloseHandle(pNotifyDataCommon->hEvent);
-        }
-
-        // Free Notify Data Memory
-        MOS_FreeMemory(pNotifyDataCommon);
-        pNotification->pHandle = nullptr;
-    }
-    return MOS_STATUS_SUCCESS;
-}
-
 float MosUtilities::MosSinc(float x)
 {
     return (MOS_ABS(x) < 1e-9f) ? 1.0F : (float)(sin(x) / x);
@@ -1034,162 +768,6 @@ void MosUtilities::MosSwizzleData(
     }
 }
 
-const uint32_t MosUtilities::GetRegAccessDataType(MOS_USER_FEATURE_VALUE_TYPE type)
-{
-    switch (type)
-    {
-    case MOS_USER_FEATURE_VALUE_TYPE_BOOL:
-    case MOS_USER_FEATURE_VALUE_TYPE_FLOAT:
-    case MOS_USER_FEATURE_VALUE_TYPE_UINT32:
-    case MOS_USER_FEATURE_VALUE_TYPE_INT32:
-        return UF_DWORD;
-    case MOS_USER_FEATURE_VALUE_TYPE_UINT64:
-    case MOS_USER_FEATURE_VALUE_TYPE_INT64:
-        return UF_QWORD;
-    case MOS_USER_FEATURE_VALUE_TYPE_MULTI_STRING:
-    case MOS_USER_FEATURE_VALUE_TYPE_STRING:
-        return UF_SZ;
-    default:
-        return UF_NONE;
-    }
-}
-
-MOS_STATUS MosUtilities::StrToMediaUserSettingValue(
-    std::string                 &strValue,
-    MOS_USER_FEATURE_VALUE_TYPE type,
-    MediaUserSetting::Value     &dstValue)
-{
-    uint32_t                base = 10;
-    if (strValue.size() > 2 && strValue.at(0) == '0' && (strValue.at(0) == 'x' || strValue.at(0) == 'X')) // 0x or 0X
-    {
-        base = 16;
-    }
-    switch (type)
-    {
-    case MOS_USER_FEATURE_VALUE_TYPE_BOOL:
-    {
-        bool value  = (std::stoul(strValue, nullptr, base) != 0) ? true : false;
-        dstValue    = value;
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_FLOAT:
-    {
-        float value = std::stof(strValue, nullptr);
-        dstValue    = value;
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_UINT32:
-    {
-        uint32_t value  = std::stoul(strValue, nullptr, base);
-        dstValue        = value;
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_INT32:
-    {
-        int32_t value   = std::stoi(strValue, nullptr, base);
-        dstValue        = value;
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_UINT64:
-    {
-        uint64_t value  = std::stoull(strValue, nullptr, base);
-        dstValue        = value;
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_INT64:
-    {
-        int64_t value   = std::stoll(strValue, nullptr, base);
-        dstValue        = value;
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_MULTI_STRING:
-    case MOS_USER_FEATURE_VALUE_TYPE_STRING:
-    {
-        dstValue = strValue;
-        break;
-    }
-    default:
-        MOS_OS_NORMALMESSAGE("Invalid data type");
-        return MOS_STATUS_UNKNOWN;
-    }
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS MosUtilities::DataToMediaUserSettingValue(
-    uint8_t                     *data,
-    size_t                      dataSize,
-    MediaUserSetting::Value     &dstValue,
-    MOS_USER_FEATURE_VALUE_TYPE type)
-{
-    MOS_STATUS status = MOS_STATUS_SUCCESS;
-    MOS_OS_CHK_NULL_RETURN(data);
-
-    auto sizeIsValid = [&](size_t requiredSize) -> bool {
-        if( requiredSize > dataSize)
-        {
-            status = MOS_STATUS_INVALID_PARAMETER;
-            return false;
-        }
-        return true;
-    };
-
-    switch (type)
-    {
-    case MOS_USER_FEATURE_VALUE_TYPE_BOOL:
-    {
-        if (sizeIsValid(sizeof(uint8_t)))
-        {
-            dstValue = (*data > 0) ? true : false;
-        }
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_FLOAT:
-    {
-        if (sizeIsValid(sizeof(float)))
-        {
-            dstValue = *((float *)data);
-        }
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_UINT32:
-    {
-        if (sizeIsValid(sizeof(uint32_t)))
-        {
-            dstValue = *((uint32_t *)data);
-        }
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_INT32:
-    {
-        if (sizeIsValid(sizeof(int32_t)))
-        {
-            dstValue = *((int32_t *)data);
-        }
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_UINT64:
-    {
-        if (sizeIsValid(sizeof(uint64_t)))
-        {
-            dstValue = *((uint64_t *)data);
-        }
-        break;
-    }
-    case MOS_USER_FEATURE_VALUE_TYPE_INT64:
-    {
-        if (sizeIsValid(sizeof(int64_t)))
-        {
-            dstValue = *((int64_t *)data);
-        }
-        break;
-    }
-    default:
-        MOS_OS_NORMALMESSAGE("Invalid data type");
-        return MOS_STATUS_UNKNOWN;
-    }
-    return status;
-}
-
 std::shared_ptr<PerfUtility> PerfUtility::instance = nullptr;
 std::mutex PerfUtility::perfMutex;
 PerfUtility* g_perfutility = PerfUtility::getInstance();
@@ -1359,27 +937,4 @@ std::string PerfUtility::getDashString(uint32_t num)
     ss.fill('-');
     ss << std::left << "" << std::endl;
     return ss.str();
-}
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-    MOS_FUNC_EXPORT void MOS_SetUltFlag(uint8_t ultFlag)
-    {
-        MosUtilities::MosSetUltFlag(ultFlag);
-    }
-
-    MOS_FUNC_EXPORT int32_t MOS_GetMemNinjaCounter()
-    {
-        return MosUtilities::MosGetMemNinjaCounter();
-    }
-
-    MOS_FUNC_EXPORT int32_t MOS_GetMemNinjaCounterGfx()
-    {
-        return MosUtilities::MosGetMemNinjaCounterGfx();
-    }
-
-#ifdef __cplusplus
-}
-#endif
+}
\ No newline at end of file
