@@ -170,13 +170,17 @@ struct mos_aub_annotation {
 
 #define BO_ALLOC_FOR_RENDER (1<<0)
 
+#define PAT_INDEX_INVALID ((uint32_t)-1)
+
 struct mos_linux_bo *mos_bo_alloc(struct mos_bufmgr *bufmgr, const char *name,
-                 unsigned long size, unsigned int alignment, int mem_type);
+                 unsigned long size, unsigned int alignment, int mem_type, unsigned int pat_index = PAT_INDEX_INVALID, bool cpu_cacheable = true);
 struct mos_linux_bo *mos_bo_alloc_for_render(struct mos_bufmgr *bufmgr,
                         const char *name,
                         unsigned long size,
                         unsigned int alignment,
-                        int mem_type);
+                        int mem_type,
+                        unsigned int pat_index = PAT_INDEX_INVALID,
+                        bool cpu_cacheable = true);
 struct mos_linux_bo *mos_bo_alloc_userptr(struct mos_bufmgr *bufmgr,
                     const char *name,
                     void *addr, uint32_t tiling_mode,
@@ -188,7 +192,9 @@ struct mos_linux_bo *mos_bo_alloc_tiled(struct mos_bufmgr *bufmgr,
                        uint32_t *tiling_mode,
                        unsigned long *pitch,
                        unsigned long flags,
-                       int mem_type);
+                       int mem_type,
+                       unsigned int pat_index = PAT_INDEX_INVALID,
+                       bool cpu_cacheable = true);
 void mos_bo_reference(struct mos_linux_bo *bo);
 void mos_bo_unreference(struct mos_linux_bo *bo);
 int mos_bo_map(struct mos_linux_bo *bo, int write_enable);
@@ -279,6 +285,8 @@ int mos_query_engines(struct mos_bufmgr *bufmgr,
                       unsigned int *nengine,
                       void *ci);
 
+size_t mos_get_engine_class_size(struct mos_bufmgr *bufmgr);
+
 int mos_set_context_param_parallel(struct mos_linux_context *ctx,
                          struct i915_engine_class_instance *ci,
                          unsigned int count);
@@ -333,10 +341,14 @@ int mos_set_context_param_sseu(struct mos_linux_context *ctx,
 uint8_t mos_switch_off_n_bits(struct mos_linux_context *ctx, uint8_t in_mask, int n);
 unsigned int mos_hweight8(struct mos_linux_context *ctx, uint8_t w);
 
+int mos_query_sys_engines(struct mos_bufmgr *bufmgr, MEDIA_SYSTEM_INFO* gfx_info);
 int mos_query_device_blob(struct mos_bufmgr *bufmgr, MEDIA_SYSTEM_INFO* gfx_info);
 int mos_query_hw_ip_version(struct mos_bufmgr *bufmgr, __u16 engine_class, void *ip_ver_info);
 int mos_get_param(int fd, int32_t param, uint32_t *param_value);
 
+struct LinuxDriverInfo;
+int mos_get_drvinfo(int  fd, struct LinuxDriverInfo *drvInfo);
+
 #if defined(__cplusplus)
 extern "C" {
 #endif
@@ -386,4 +398,7 @@ drm_export bool mos_bo_is_exec_object_async(struct mos_linux_bo *bo);
 #define PLATFORM_INFORMATION_IS_SERVER     0x1
 uint64_t mos_get_platform_information(struct mos_bufmgr *bufmgr);
 void mos_set_platform_information(struct mos_bufmgr *bufmgr, uint64_t p);
+bool mos_has_bsd2(struct mos_bufmgr *bufmgr);
+int mos_get_ts_frequency(struct mos_bufmgr *bufmgr, uint32_t *ts_freq);
+void mos_enable_turbo_boost(struct mos_bufmgr *bufmgr);
 #endif /* INTEL_BUFMGR_H */
