@@ -48,7 +48,7 @@ struct mos_bufmgr {
      * using bo_map() or drm_intel_gem_bo_map_gtt() to be used by the CPU.
      */
     struct mos_linux_bo *(*bo_alloc) (struct mos_bufmgr *bufmgr, const char *name,
-                   unsigned long size, unsigned int alignment, int mem_type);
+                   unsigned long size, unsigned int alignment, int mem_type, unsigned int pat_index, bool cpu_cacheable);
 
     /**
      * Allocate a buffer object, hinting that it will be used as a
@@ -60,7 +60,9 @@ struct mos_bufmgr {
                           const char *name,
                           unsigned long size,
                           unsigned int alignment,
-                          int mem_type);
+                          int mem_type,
+                          unsigned int pat_index,
+                          bool cpu_cacheable);
 
     /**
      * Allocate a buffer object from an existing user accessible
@@ -95,7 +97,9 @@ struct mos_bufmgr {
                      uint32_t *tiling_mode,
                      unsigned long *pitch,
                      unsigned long flags,
-                     int mem_type);
+                     int mem_type,
+                     unsigned int pat_index,
+                     bool cpu_cacheable);
 
     /** Takes a reference on a buffer object */
     void (*bo_reference) (struct mos_linux_bo *bo);
@@ -386,6 +390,9 @@ struct mos_bufmgr {
                           __u64 caps,
                           unsigned int *nengine,
                           void *ci);
+
+    size_t (*get_engine_class_size)();
+
     int (*set_context_param)(struct mos_linux_context *ctx,
                     uint32_t size,
                     uint64_t param,
@@ -418,10 +425,14 @@ struct mos_bufmgr {
                     struct drm_i915_gem_context_param_sseu *sseu);
     int (*set_context_param_sseu)(struct mos_linux_context *ctx,
                     struct drm_i915_gem_context_param_sseu sseu);
+    int (*query_sys_engines)(struct mos_bufmgr *bufmgr, MEDIA_SYSTEM_INFO* gfx_info);
     int (*query_device_blob)(struct mos_bufmgr *bufmgr, MEDIA_SYSTEM_INFO* gfx_info);
     int (*query_hw_ip_version)(struct mos_bufmgr *bufmgr, __u16 engine_class, void *ip_ver_info);
     uint64_t (*get_platform_information)(struct mos_bufmgr *bufmgr);
     void (*set_platform_information)(struct mos_bufmgr *bufmgr, uint64_t p);
+    int (*get_ts_frequency)(struct mos_bufmgr *bufmgr, uint32_t *ts_freq);
+    bool (*has_bsd2)(struct mos_bufmgr *bufmgr);
+    void (*enable_turbo_boost)(struct mos_bufmgr *bufmgr);
     uint8_t (*switch_off_n_bits)(struct mos_linux_context *ctx, uint8_t in_mask, int n);
     unsigned int (*hweight8)(struct mos_linux_context *ctx, uint8_t w);
 
