@@ -49,7 +49,7 @@
 
 struct mos_linux_bo *
 mos_bo_alloc(struct mos_bufmgr *bufmgr, const char *name,
-           unsigned long size, unsigned int alignment, int mem_type)
+           unsigned long size, unsigned int alignment, int mem_type, unsigned int pat_index, bool cpu_cacheable)
 {
     if(!bufmgr)
     {
@@ -59,7 +59,7 @@ mos_bo_alloc(struct mos_bufmgr *bufmgr, const char *name,
 
     if (bufmgr->bo_alloc)
     {
-        return bufmgr->bo_alloc(bufmgr, name, size, alignment, mem_type);
+        return bufmgr->bo_alloc(bufmgr, name, size, alignment, mem_type, pat_index, cpu_cacheable);
     }
     else
     {
@@ -70,7 +70,7 @@ mos_bo_alloc(struct mos_bufmgr *bufmgr, const char *name,
 
 struct mos_linux_bo *
 mos_bo_alloc_for_render(struct mos_bufmgr *bufmgr, const char *name,
-                  unsigned long size, unsigned int alignment, int mem_type)
+                  unsigned long size, unsigned int alignment, int mem_type, unsigned int pat_index, bool cpu_cacheable)
 {
     if(!bufmgr)
     {
@@ -80,7 +80,7 @@ mos_bo_alloc_for_render(struct mos_bufmgr *bufmgr, const char *name,
 
     if (bufmgr->bo_alloc_for_render)
     {
-        return bufmgr->bo_alloc_for_render(bufmgr, name, size, alignment, mem_type);
+        return bufmgr->bo_alloc_for_render(bufmgr, name, size, alignment, mem_type, pat_index, cpu_cacheable);
     }
     else
     {
@@ -119,7 +119,7 @@ struct mos_linux_bo *
 mos_bo_alloc_tiled(struct mos_bufmgr *bufmgr, const char *name,
                         int x, int y, int cpp, uint32_t *tiling_mode,
                         unsigned long *pitch, unsigned long flags,
-                        int mem_type)
+                        int mem_type, unsigned int pat_index, bool cpu_cacheable)
 {
     if(!bufmgr)
     {
@@ -130,7 +130,7 @@ mos_bo_alloc_tiled(struct mos_bufmgr *bufmgr, const char *name,
     if (bufmgr->bo_alloc_tiled)
     {
         return bufmgr->bo_alloc_tiled(bufmgr, name, x, y, cpp,
-                      tiling_mode, pitch, flags, mem_type);
+                      tiling_mode, pitch, flags, mem_type, pat_index, cpu_cacheable);
     }
     else
     {
@@ -1278,6 +1278,47 @@ mos_query_engines(struct mos_bufmgr *bufmgr,
     }
 }
 
+size_t
+mos_get_engine_class_size(struct mos_bufmgr *bufmgr)
+{
+    if(!bufmgr)
+    {
+        MOS_OS_CRITICALMESSAGE("Input null ptr\n");
+        return 0;
+    }
+
+    if (bufmgr->get_engine_class_size)
+    {
+        return bufmgr->get_engine_class_size();
+    }
+    else
+    {
+        MOS_OS_CRITICALMESSAGE("Unsupported\n");
+        return 0;
+    }
+}
+
+int
+mos_query_sys_engines(struct mos_bufmgr *bufmgr, MEDIA_SYSTEM_INFO* gfx_info)
+{
+    if(!bufmgr)
+    {
+        MOS_OS_CRITICALMESSAGE("Input null ptr\n");
+        return -EINVAL;
+    }
+
+    if (bufmgr->query_sys_engines)
+    {
+        return bufmgr->query_sys_engines(bufmgr, gfx_info);
+    }
+    else
+    {
+        MOS_OS_CRITICALMESSAGE("Unsupported\n");
+        return -EPERM;
+    }
+
+}
+
 int
 mos_query_device_blob(struct mos_bufmgr *bufmgr, MEDIA_SYSTEM_INFO* gfx_info)
 {
@@ -1358,6 +1399,66 @@ mos_set_platform_information(struct mos_bufmgr *bufmgr, uint64_t p)
     }
 }
 
+bool
+mos_has_bsd2(struct mos_bufmgr *bufmgr)
+{
+    if(!bufmgr)
+    {
+        MOS_OS_CRITICALMESSAGE("Input null ptr\n");
+        return false;
+    }
+
+    if (bufmgr->has_bsd2)
+    {
+        return bufmgr->has_bsd2(bufmgr);
+    }
+    else
+    {
+        MOS_OS_CRITICALMESSAGE("Unsupported\n");
+        return false;
+    }
+}
+
+void
+mos_enable_turbo_boost(struct mos_bufmgr *bufmgr)
+{
+    if(!bufmgr)
+    {
+        MOS_OS_CRITICALMESSAGE("Input null ptr\n");
+        return;
+    }
+
+    if (bufmgr->enable_turbo_boost)
+    {
+        bufmgr->enable_turbo_boost(bufmgr);
+    }
+    else
+    {
+        MOS_OS_CRITICALMESSAGE("Unsupported\n");
+    }
+}
+
+int
+mos_get_ts_frequency(struct mos_bufmgr *bufmgr, uint32_t *ts_freq)
+{
+    if(!bufmgr)
+    {
+        MOS_OS_CRITICALMESSAGE("Input null ptr\n");
+        return -EINVAL;
+    }
+
+    if (bufmgr->get_ts_frequency)
+    {
+        return bufmgr->get_ts_frequency(bufmgr, ts_freq);
+    }
+    else
+    {
+        MOS_OS_CRITICALMESSAGE("Unsupported\n");
+        return -EPERM;
+    }
+}
+
+
 int
 mos_reg_read(struct mos_bufmgr *bufmgr,
                uint32_t offset,
