@@ -403,11 +403,11 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
         }
         if (i == *nengine)
         {
-            streamState->bGucSubmission = false;
+            streamState->bParallelSubmission = false;
         }
         else
         {
-            streamState->bGucSubmission = true;
+            streamState->bParallelSubmission = true;
             //create context with different width
             for(i = 1; i < *nengine; i++)
             {
@@ -561,7 +561,8 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
     {
         bool         isEngineSelectEnable = false;
         unsigned int nengine              = 0;
-        struct i915_engine_class_instance *engine_map = nullptr;
+        size_t       engine_class_size    = 0;
+        void         *engine_map          = nullptr;
 
         MOS_TraceEventExt(EVENT_GPU_CONTEXT_CREATE, EVENT_TYPE_START,
                           &gpuNode, sizeof(gpuNode), nullptr, 0);
@@ -573,25 +574,31 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
             MOS_OS_ASSERTMESSAGE("Failed to query engines count.\n");
             return MOS_STATUS_UNKNOWN;
         }
-        engine_map = (struct i915_engine_class_instance *)MOS_AllocAndZeroMemory(nengine * sizeof(struct i915_engine_class_instance));
+        engine_class_size = mos_get_engine_class_size(osParameters->bufmgr);
+        if (!engine_class_size)
+        {
+            MOS_OS_ASSERTMESSAGE("Failed to get engine class instance size.\n");
+            return MOS_STATUS_UNKNOWN;
+        }
+        engine_map = MOS_AllocAndZeroMemory(nengine * engine_class_size);
         MOS_OS_CHK_NULL_RETURN(engine_map);
 
         if (gpuNode == MOS_GPU_NODE_3D)
         {
-            eStatus = Init3DCtx(osParameters, createOption, &nengine, (void *)engine_map);
+            eStatus = Init3DCtx(osParameters, createOption, &nengine, engine_map);
         }
         else if (gpuNode == MOS_GPU_NODE_COMPUTE)
         {
-            eStatus = InitComputeCtx(osParameters, &nengine, (void *)engine_map, gpuNode, &isEngineSelectEnable);
+            eStatus = InitComputeCtx(osParameters, &nengine, engine_map, gpuNode, &isEngineSelectEnable);
         }
         else if (gpuNode == MOS_GPU_NODE_VIDEO || gpuNode == MOS_GPU_NODE_VIDEO2
                 || gpuNode == MOS_GPU_NODE_VE)
         {
-            eStatus = InitVdVeCtx(osParameters, streamState, createOption, &nengine, (void *)engine_map, gpuNode, &isEngineSelectEnable);
+            eStatus = InitVdVeCtx(osParameters, streamState, createOption, &nengine, engine_map, gpuNode, &isEngineSelectEnable);
         }
         else if (gpuNode == MOS_GPU_NODE_BLT)
         {
-            eStatus = InitBltCtx(osParameters, &nengine, (void *)engine_map);
+            eStatus = InitBltCtx(osParameters, &nengine, engine_map);
         }
         else
         {
@@ -610,8 +617,6 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
                           &nengine, sizeof(nengine));
     }
 
-    MOS_OS_CHK_STATUS_RETURN(ReportMemoryInfo(osParameters->bufmgr));
-
     return eStatus;
 }
 
@@ -653,10 +658,15 @@ void GpuContextSpecificNext::Clear()
     MosUtilities::MosDestroyMutex(m_cmdBufPoolMutex);
     m_cmdBufPoolMutex = nullptr;
     MOS_SafeFreeMemory(m_commandBuffer);
+    m_commandBuffer = nullptr;
     MOS_SafeFreeMemory(m_allocationList);
+    m_allocationList = nullptr;
     MOS_SafeFreeMemory(m_patchLocationList);
+    m_patchLocationList = nullptr;
     MOS_SafeFreeMemory(m_attachedResources);
+    m_attachedResources = nullptr;
     MOS_SafeFreeMemory(m_writeModeList);
+    m_writeModeList = nullptr;
 
     for (int i=0; i<MAX_ENGINE_INSTANCE_NUM; i++)
     {
@@ -1502,7 +1512,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
         {
             if (cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_MASK)
             {
-                if (scalaEnabled && !streamState->bGucSubmission)
+                if (scalaEnabled && !streamState->bParallelSubmission)
                 {
                     uint32_t secondaryIndex = 0;
                     it = m_secondaryCmdBufs.begin();
@@ -1526,7 +1536,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
                         it++;
                     }
                 }
-                else if(scalaEnabled && streamState->bGucSubmission)
+                else if(scalaEnabled && streamState->bParallelSubmission)
                 {
                     ret = ParallelSubmitCommands(m_secondaryCmdBufs,
                                          perStreamParameters,
@@ -1721,15 +1731,10 @@ int32_t GpuContextSpecificNext::SubmitPipeCommands(
         }
     }
 
-    //Keep FE and BE0 running on same engine for VT decode
-    if((cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_ALONE)
-        || (cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_MASTER))
+    if(cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_MASTER)
     {
-        if(cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_MASTER)
-        {
-            //Only master pipe needs fence out flag
-            fence_flag = I915_EXEC_FENCE_OUT;
-        }
+        //Only master pipe needs fence out flag
+        fence_flag = I915_EXEC_FENCE_OUT;
         queue = m_i915Context[1];
     }
 
