@@ -74,6 +74,13 @@ MOS_STATUS GraphicsResourceSpecificNext::Allocate(OsContextNext* osContextPtr, C
         return MOS_STATUS_INVALID_HANDLE;
     }
 
+    GMM_CLIENT_CONTEXT    *gmmClientContext = pOsContextSpecific->GetGmmClientContext();
+    if (nullptr == gmmClientContext)
+    {
+        MOS_OS_ASSERTMESSAGE("Get GMM Client Context failed.");
+        return MOS_STATUS_INVALID_HANDLE;
+    }
+
     MOS_STATUS         status          = MOS_STATUS_SUCCESS;
     uint32_t           tileFormatLinux = I915_TILING_NONE;
     uint32_t           alignedHeight   = params.m_height;
@@ -250,6 +257,9 @@ MOS_STATUS GraphicsResourceSpecificNext::Allocate(OsContextNext* osContextPtr, C
     char bufName[m_maxBufNameLength];
     MosUtilities::MosSecureStrcpy(bufName, m_maxBufNameLength, params.m_name.c_str());
 
+    unsigned int patIndex = MosInterface::GetPATIndexFromGmm(gmmClientContext, gmmResourceInfoPtr);
+    bool isCpuCacheable   = gmmResourceInfoPtr->GetResFlags().Info.Cacheable;
+
     MOS_TraceEventExt(EVENT_RESOURCE_ALLOCATE, EVENT_TYPE_START, nullptr, 0, nullptr, 0);
     if (nullptr != params.m_pSystemMemory)
     {
@@ -264,7 +274,7 @@ MOS_STATUS GraphicsResourceSpecificNext::Allocate(OsContextNext* osContextPtr, C
     // Only Linear and Y TILE supported
     else if (tileFormatLinux == I915_TILING_NONE)
     {
-        boPtr = mos_bo_alloc(pOsContextSpecific->m_bufmgr, bufName, bufSize, 4096, mem_type);
+        boPtr = mos_bo_alloc(pOsContextSpecific->m_bufmgr, bufName, bufSize, 4096, mem_type, patIndex, isCpuCacheable);
     }
     else
     {
@@ -276,7 +286,9 @@ MOS_STATUS GraphicsResourceSpecificNext::Allocate(OsContextNext* osContextPtr, C
                         &tileFormatLinux,
                         &linuxPitch,
                         0,
-                        mem_type);
+                        mem_type,
+                        patIndex,
+                        isCpuCacheable);
         bufPitch = (uint32_t)linuxPitch;
     }
 
@@ -628,6 +640,8 @@ MOS_STATUS GraphicsResourceSpecificNext::AllocateExternalResource(
     GMM_RESCREATE_PARAMS gmmParams;
     GMM_RESOURCE_INFO *gmmResourceInfo = nullptr;
     GMM_RESOURCE_TYPE resourceType = RESOURCE_2D;
+    unsigned int patIndex = PAT_INDEX_INVALID;
+    bool isCpuCacheable = true;
 
     MosUtilities::MosZeroMemory(&gmmParams, sizeof(gmmParams));
 
@@ -725,6 +739,7 @@ MOS_STATUS GraphicsResourceSpecificNext::AllocateExternalResource(
     }
     gmmParams.Flags.Info.LocalOnly = MEDIA_IS_SKU(&perStreamParameters->m_skuTable, FtrLocalMemory);
 
+    MOS_OS_CHK_NULL_RETURN(perStreamParameters->pGmmClientContext);
     resource->pGmmResInfo = gmmResourceInfo = perStreamParameters->pGmmClientContext->CreateResInfoObject(&gmmParams);
 
     MOS_OS_CHK_NULL_RETURN(gmmResourceInfo);
@@ -758,10 +773,13 @@ MOS_STATUS GraphicsResourceSpecificNext::AllocateExternalResource(
     iSize   = GFX_ULONG_CAST(gmmResourceInfo->GetSizeSurface());
     iHeight = gmmResourceInfo->GetBaseHeight();
 
+    patIndex = MosInterface::GetPATIndexFromGmm(perStreamParameters->pGmmClientContext, gmmResourceInfo);
+    isCpuCacheable = gmmResourceInfo->GetResFlags().Info.Cacheable;
+
     // Only Linear and Y TILE supported
     if (tileformat_linux == I915_TILING_NONE)
     {
-        bo = mos_bo_alloc(perStreamParameters->bufmgr, bufname, iSize, 4096, MOS_MEMPOOL_VIDEOMEMORY);
+        bo = mos_bo_alloc(perStreamParameters->bufmgr, bufname, iSize, 4096, MOS_MEMPOOL_VIDEOMEMORY, patIndex, isCpuCacheable);
     }
     else
     {
@@ -773,7 +791,9 @@ MOS_STATUS GraphicsResourceSpecificNext::AllocateExternalResource(
                         &tileformat_linux,
                         &ulPitch,
                         0,
-                        MOS_MEMPOOL_VIDEOMEMORY);
+                        MOS_MEMPOOL_VIDEOMEMORY,
+                        patIndex,
+                        isCpuCacheable);
         iPitch = (int32_t)ulPitch;
     }
 
